#!/bin/bash
# Threshold plugin 2.1c for cacti 8.6g
#
# Copyright 2005 Aurelio DeSimone
# adesimone@ciscoconfigbuilder.com
# 
# Use at your own risk.  NO Warranty or Guarantee given.
#
# Some code may have been used from other parts of cacti - copyright of Ian Berry
#

#
# Usage
#
usage()
{
        echo 
        echo "Usage : ./install.sh <cacti install folder> [DB username] [DB password]"
        echo
        exit $1
}


#
# Check parameters of application
#
if [ $# -gt 0 ]; then
        cactibasedir=$1
        database_username=$2
        database_password=$3
else
        usage 0
fi

#
# Check If Cacti is Installed
#
if [ -f "$cactibasedir/poller.php" ]
then
        echo "Directory Check OK"
else
        echo "Cacti not found.  Please check syntax"
        exit
fi

echo "Installing Treshold in $cactibasedir"

if [ -f "$cactibasedir/include/config.php" ]
then    
        echo "Found Cacti Config File"
        cacti_configfile=$cactibasedir/include/config.php
        cactidbname=`grep database_default $cacti_configfile | head -1 | awk -F '"' '{print $2}'`
        database_username=`grep database_username $cacti_configfile | head -1 | awk -F '"' '{print $2}'`
        database_password=`grep database_password $cacti_configfile | head -1 | awk -F '"' '{print $2}'`
        cacti_version=`grep cacti_version $cacti_configfile | awk -F '"' '{print $4}'`
else
        echo "Cacti not found.  Please check syntax"
        exit
fi

#
# Check Version
#
if [ "$cacti_version" == "0.8.6g" ]
        then
                echo
                echo "I have found Cacti 0.8.6g"
                echo
        else
                echo
                echo "Sorry this is not Cacti 0.8.6g"
                echo "Your installed version is $cacti_version"
                echo "Install script will end"
                echo "WARNING: If you install, Cacti may be unstable."
                echo
                exit
fi

#
# Check If Treshold is Already Installed
#
checkold=`grep -i thold $cactibasedir/* | grep -v zip | wc -l | awk '{print $1}'`

if [ $checkold -eq 0 ]
        then
                echo "This is a new install.."
        else
                echo "An installation seems already be present."
                echo "This version is not back-ward compatible."
                echo "WARNING: If you proceed, all old thold settings will be erased."
                echo -n "Do you want to continue (y/n):"
                read var1
                var2="y"
                if [ "$var1" == "$var2" ]
                        then
                                echo "Overwriting existing install..."
                else
                        exit
                fi

fi

#
# Check MySQL
#
echo "show tables;" > quit.txt
echo
echo "Check MySQL Connection"

checkdbconn=`mysql $cactidbname --user=$database_username --password=$database_password  < quit.txt | grep host_template_snmp_query | wc -l | awk '{print $1}'`
if [ $checkdbconn -eq 1 ]
        then
                echo "DB login OK"
        else
                if [ "$database_username" == "" ]
                        then
                                echo "Database login failed.  Please specify cacti database login - i.e. install.sh /var/www/html/cacti cactiuer cactipass"
				usage 0
				exit
                        else
                                echo "database username and pass given"
                                checkdbagain=`mysql $cactidbname --user=$database_username --password=$database_password < quit.txt | grep host_template_snmp_query | wc -l | awk '{print $1}'`
                                if [ $checkdbagain -eq 1 ]
                                        then
                                                echo "DB login OK"
                                        else
						echo "**************************************************************"
                                                echo "WARNING: - Database login still failed - "
                                                echo "You will have to import manually using 'mysql cacti < thold.sql"
						echo "**************************************************************"
                                fi
                fi
fi
rm -rf quit.txt

echo " "
echo "WARNING: you may want to backup files & cacti database before proceeding."
echo "An uninstall script is provided to remove & restore modified files."
echo "Use at your own risk.  NO Warranty or Guarantee given."
echo "If you continue, you agree not to hold me liable for damages or loss of data."
echo "press CTRL+C in the next 5 seconds to stop"
sleep 6
echo " "

#
# Backup Old Files
# 
echo
echo "Backing up files..."
cp $cactibasedir/graphs_new.php $cactibasedir/graphs_new.php.bak
cp $cactibasedir/data_sources.php $cactibasedir/data_sources.php.bak
cp $cactibasedir/lib/functions.php $cactibasedir/lib/functions.php.bak
cp $cactibasedir/include/config_arrays.php $cactibasedir/include/config_arrays.php.bak
cp $cactibasedir/include/config_settings.php $cactibasedir/include/config_settings.php.bak
cp $cactibasedir/include/top_header.php $cactibasedir/include/top_header.php.bak
cp $cactibasedir/include/top_graph_header.php $cactibasedir/include/top_graph_header.php.bak
mysqldump $cactidbname --user=$database_username --password=$database_password > $cactibasedir/cacti_pre_thold2.1a.backup.sql

#
# Add tables
#
echo
echo "Adding SQL tables..."
mysql $cactidbname --user=$database_username --password=$database_password < thold.sql

#
# Install files
#
echo
echo "Installing new files..."
mkdir $cactibasedir/thold/
touch $cactibasedir/log/thold.log

echo
echo -n "Do you prefer to use patch command ? (y/n)"
read var1
var2="y"
echo
echo

if [ "$var1" == "$var2" ]
	then
		echo "Patching files ..."
		if [ $already_exist -eq 1 ]
			then
				echo "I cannot patch files. Thold is already installed"
				exit
		fi
		echo "Patching include/config_arrays.php"
		patch -p1 $cactibasedir/include/config_arrays.php diff/config_arrays.diff
		echo "Patching include/config_settings.php"
		patch -p1 $cactibasedir/include/config_settings.php diff/config_settings.diff
		echo "Patching data_sources.php"
		patch -p1 $cactibasedir/data_sources.php diff/data_sources.diff
		echo "Patching lib/functions.php"
		patch -p1 $cactibasedir/lib/functions.php diff/functions.diff
		echo "Patching graphs_new.php"
		patch -p1 $cactibasedir/graphs_new.php diff/graphs_new.diff
		echo "Patching include/top_graph_hearder.php"
		patch -p1 $cactibasedir/include/top_graph_header.php diff/top_graph_header.diff
		echo "Patching unclude/top_header.php"
		patch -p1 $cactibasedir/include/top_header.php diff/top_header.diff
		
	else
		echo "Copying files ..."
		cp check-thold.php $cactibasedir/thold/
		cp thold.php $cactibasedir/
		cp listthold.php $cactibasedir/
		cp tab_thold.gif $cactibasedir/images/
		cp graph_thold.php $cactibasedir/
		cp config_arrays.php $cactibasedir/include/
		cp config_settings.php $cactibasedir/include/
		cp data_sources.php $cactibasedir/
		cp graphs_new.php $cactibasedir/
		cp functions.php $cactibasedir/lib/
		cp top_graph_header.php $cactibasedir/include/
		cp top_header.php $cactibasedir/include/
		cp thold-functions.php $cactibasedir/lib/

fi

echo "***************************************************************************************************************** "
echo "Installation complete.  MAKE SURE YOU MODIFY YOUR CRONTAB (crontab -e on most systems):"
echo " "
echo "Replace the line:"
echo "*/5 * * * * /usr/bin/php $1/poller.php > /dev/null > /dev/null 2>&1"
echo "With:"
echo "*/5 * * * * /usr/bin/php $1/poller.php >/dev/null 2>&1 && /usr/bin/php $1/thold/check-thold.php > /dev/null 2>&1"
echo "***************************************************************************************************************** "
